%bcond docs 1
%bcond introspection 1

# The shared library version
%global soversion 0.5

Name:           libipuz
Version:        0.5.3
Release:        1.20250627054832570899.master.23.g5e2493c%{?dist}
Summary:        Library for parsing .ipuz puzzle files

License:        LGPL-2.1-or-later OR MIT
URL:            https://gitlab.gnome.org/jrb/libipuz
Source:         libipuz-0.5.3.tar.gz
# write the https URL out when saving a barred or nonogram puzzle
# Read both http://libipuz.org and https://libipuz.org for custom kinds
# Initialize autoptr to NULL

BuildRequires:  cargo-rpm-macros >= 24
BuildRequires:  cmake
BuildRequires:  gcc
BuildRequires:  gettext
BuildRequires:  meson
BuildRequires:  python3
BuildRequires:  sed
%if %{with docs}
BuildRequires:  python3dist(sphinx)
BuildRequires:  python3dist(sphinx-rtd-theme)
BuildRequires:  python3dist(myst-parser)
%endif

BuildRequires:  glib2-devel
BuildRequires:  json-glib-devel
%if %{with introspection}
BuildRequires:  gi-docgen
BuildRequires:  gobject-introspection-devel
%endif

%description
This is a library for parsing .ipuz puzzle files, for crossword puzzles,
sudokus, etc. The library only handles crosswords for now.

%package        devel
Summary:        Development files for %{name}
Requires:       %{name}%{?_isa} = %{version}-%{release}
%if %{with docs}
Suggests:       %{name}-doc = %{version}-%{release}
%endif

%description    devel
The %{name}-devel package contains libraries and header files for
developing applications that use %{name}.

%if %{with docs}
%package        doc
Summary:        Documentation for %{name}
BuildArch:      noarch

%description    doc
This package contains additional documentation for %{name}.
%endif

%package        tests
Summary:        Tests for %{name}
Requires:       %{name}%{?_isa} = %{version}-%{release}

%description    tests
The %{name}-tests package contains tests for %{name}.

%prep
%autosetup -p1 -n libipuz-0.5.3
%cargo_prep

# Drop version locks
rm libipuz/rust/Cargo.lock
sed -i '/Cargo.lock/d' libipuz/rust/meson.build

%generate_buildrequires
cd libipuz/rust
%cargo_generate_buildrequires

%build
%meson
%meson_build

%if %{with docs}
sphinx-build-3 docs html
rm -rf html/.{doctrees,buildinfo}
%endif

%install
%meson_install

%check
%meson_test

%files
%license LICENSE COPYING.LGPL COPYING.MIT
%doc README.md NEWS.md
%{_libdir}/lib%{name}-%{soversion}.so

%files devel
%{_includedir}/*
%if %{with introspection}
%{_datadir}/gir-1.0/Ipuz-1.0.gir
%{_libdir}/girepository-1.0/Ipuz-1.0.typelib
%endif
%{_libdir}/pkgconfig/%{name}-%{soversion}.pc

%if %{with docs}
%files doc
%license LICENSE COPYING.LGPL COPYING.MIT
%doc html
%if %{with introspection}
%doc %{_docdir}/%{name}-1.0/
%endif
%endif

%files tests
%dir %{_datadir}/installed-tests
%{_datadir}/installed-tests/%{name}-1.0
%dir %{_libexecdir}/installed-tests
%{_libexecdir}/installed-tests/%{name}-1.0

%changelog
* Fri Jun 27 2025 Packit <hello@packit.dev> - 0.5.3-1.20250627054832570899.master.23.g5e2493c
- Add default-domain and msgid-bugs-address to intltool args (Jonathan Blandford)
- Move i18n definiton to the top meson.build file (Jonathan Blandford)
- Add gettext support to direction_to_string (Jonathan Blandford)
- remove gettext from property descriptions (Jonathan Blandford)
- Free guesses when done with it (Jonathan Blandford)
- Forgot to add this file (Jonathan Blandford)
- Add ipuz_acrostic_get_guess_string() with tests (Jonathan Blandford)
- Update deprecated API from the rand crate (Federico Mena Quintero)
- Update crates (Federico Mena Quintero)
- CI: Move to CI templates hosted on gitlab.gnome.org (Federico Mena Quintero)
- CI: Update Rust toolchain versions (Federico Mena Quintero)
- IpuzAcrostic: Rename ipuz_acrostic_(set|clear)_answers? APIs (Tanmay Patil)
- docs: document ipuz-extensions for acrostics (Tanmay Patil)
- ipuz-acrostic: store original quote in ipuz format (Tanmay Patil)
- Run `cargo update` (Jonathan Blandford)
- Read both http://libipuz.org and https://libipuz.org for custom kinds (Jonathan Blandford)
- write the https URL out when saving a barred or nonogram puzzle (Jonathan Blandford)
- Initialize autoptr to NULL (Jonathan Blandford)
- post release bump (Jonathan Blandford)
